<!-- warning: Please don't edit this file. It was automatically generated. -->

# winrt-Windows.Globalization.PhoneNumberFormatting

Windows Runtime (WinRT) APIs for for the `Windows.Globalization.PhoneNumberFormatting` namespace.

This package provides the `winrt.windows.globalization.phonenumberformatting` module.
